@@ -318,8 +318,9 @@ class MessagesManager(CommonTreeGridManager):
                     message.soft_delete()
                 else:
                     message = super().get(id=id)
-                    if not request.is_admin and not request.is_develop and message.user.id != request.user_id:
-                        raise Exception(f'Удаление может выполнить только автор.')
+                    if not message.user.props.bot.is_set:
+                        if not request.is_admin and not request.is_develop and message.user.id != request.user_id:
+                            raise Exception(f'Удаление может выполнить только автор.')
 
                     Messages_files_refs.objects.filter(message=message).delete()
                     qty, _ = message.delete()
